==> wow-core-2.8.25-sources.jar: me/ahoo/wow/exception/ErrorCodeMapping.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.exception

import org.slf4j.LoggerFactory
import java.util.concurrent.ConcurrentHashMap

object ErrorCodeMapping {
    private val log = LoggerFactory.getLogger(ErrorCodeMapping::class.java)
    private val registrar = ConcurrentHashMap<Class<out Throwable>, String>()

    fun register(throwableClass: Class<out Throwable>, errorCode: String) {
        val previous = registrar.put(throwableClass, errorCode)
        if (log.isInfoEnabled) {
            log.info("Register - errorCode:[{}] - previous:[{}],current:[{}].", errorCode, previous, throwableClass)
        }
    }

    fun unregister(throwableClass: Class<out Throwable>) {
        val removed = registrar.remove(throwableClass)
        if (log.isInfoEnabled) {
            log.info("Unregister - throwableClass:[{}] - removed:[{}].", throwableClass, removed)
        }
    }

    fun getErrorCode(throwableClass: Class<out Throwable>): String? {
        return registrar[throwableClass]
    }
}

==> wow-core-3.12.6-sources.jar: me/ahoo/wow/exception/ErrorCodeMapping.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.exception

import org.slf4j.LoggerFactory
import java.util.concurrent.ConcurrentHashMap

object ErrorCodeMapping {
    private val log = LoggerFactory.getLogger(ErrorCodeMapping::class.java)
    private val registrar = ConcurrentHashMap<Class<out Throwable>, String>()

    fun register(throwableClass: Class<out Throwable>, errorCode: String) {
        val previous = registrar.put(throwableClass, errorCode)
        if (log.isInfoEnabled) {
            log.info(
                "Register - throwableClass:[{}] - previous:[{}],current:[{}].",
                throwableClass,
                previous,
                errorCode
            )
        }
    }

    fun unregister(throwableClass: Class<out Throwable>) {
        val removed = registrar.remove(throwableClass)
        if (log.isInfoEnabled) {
            log.info("Unregister - throwableClass:[{}] - removed:[{}].", throwableClass, removed)
        }
    }

    fun getErrorCode(throwableClass: Class<out Throwable>): String? {
        return registrar[throwableClass]
    }
}
